==> regina-normal_7.1.orig.tar.gz: regina-7.1/python/utilities/randutils.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2022, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#include "../pybind11/pybind11.h"
#include "utilities/randutils.h"
#include "../helpers.h"

using regina::RandomEngine;

void addRandUtils(pybind11::module_& m) {
    auto c = pybind11::class_<RandomEngine>(m, "RandomEngine")
        .def_static("rand", &RandomEngine::rand<long>)
        .def_static("reseedWithHardware", &RandomEngine::reseedWithHardware)
        .def_static("reseedWithDefault", &RandomEngine::reseedWithDefault)
    ;
    regina::python::no_eq_operators(c);
}

==> regina-normal_7.2.orig.tar.gz: regina-7.2/python/utilities/randutils.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2022, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#include "../pybind11/pybind11.h"
#include "utilities/randutils.h"
#include "../helpers.h"
#include "../docstrings/utilities/randutils.h"

using regina::RandomEngine;

void addRandUtils(pybind11::module_& m) {
    RDOC_SCOPE_BEGIN(RandomEngine)

    auto c = pybind11::class_<RandomEngine>(m, "RandomEngine", rdoc_scope)
        .def_static("rand", &RandomEngine::rand<long>, rdoc::rand)
        .def_static("reseedWithHardware", &RandomEngine::reseedWithHardware,
            rdoc::reseedWithHardware)
        .def_static("reseedWithDefault", &RandomEngine::reseedWithDefault,
            rdoc::reseedWithDefault)
    ;
    regina::python::no_eq_static(c);

    RDOC_SCOPE_END
}
